/*
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *  Copyright (c) 2007 Sven Langkamp <sven.langkamp@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_IMAGE_RESIZE_COMMAND_H_
#define KIS_IMAGE_RESIZE_COMMAND_H_

#include "krita_export.h"
#include "kis_types.h"

#include <kundo2command.h>
#include <QSize>


class KRITAIMAGE_EXPORT KisImageResizeCommand : public KUndo2Command
{
public:
    KisImageResizeCommand(KisImageWSP image, const QSize& newRect);

    void redo();
    void undo();

private:
    QSize m_sizeBefore;
    QSize m_sizeAfter;
    KisImageWSP m_image;
};

#endif
